@@ -15,7 +15,7 @@ class NumberSize(CloudFormationLintRule):
     id = 'E3034'
     shortdesc = 'Check if a number is between min and max'
     description = 'Check numbers (integers and floats) for its value being between the minimum and maximum'
-    source_url = 'https://github.com/awslabs/cfn-python-lint/blob/master/docs/cfn-resource-specification.md#allowedpattern'
+    source_url = 'https://github.com/awslabs/cfn-python-lint/blob/main/docs/cfn-resource-specification.md#allowedpattern'
     tags = ['resources', 'property', 'number', 'size']
 
     def initialize(self, cfn):
